<?php
/**
 * Plugin tinyEditor
 * Fork de plxEditor
 *
 * @author	J.P. Pourrez "bazooka07", Stephane F
 **/

$lang = filter_input(INPUT_GET, 'lang', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => '@^\w{1,3}(-\w{1,5})?@')));
if(!empty($lang)) {
	session_start();
	# On retourne la liste des traductions au format JSON
	if($_SESSION['admin_lang'] == $lang) {
		$token = filter_input(INPUT_GET, 'token', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => '@^\w+$@')));
		if(empty($token) or empty($_SESSION['formtoken'][$token]) or $_SESSION['formtoken'][$token] < time() - 3600) {
			if(isset($_SESSION['formtoken'][$token])) {
				unset($_SESSION['formtoken'][$token]);
			}

			header($_SERVER['SERVER_PROTOCOL'] . ' 401 Invalid token');
			die('Security error : invalid or expired token');
		}

		$filename = 'lang/' . $lang . '.php';
		if(file_exists($filename)) {
			header('Cache-Control: private, max-age=7200');
			header('Expires: ' . date(DATE_RFC7231, (time() + 7200)));
			header('Last-Modified: ' . date(DATE_RFC7231, filemtime($filename)));
			header('Content-Type: application/json');
			include $filename;
			echo json_encode($LANG, JSON_UNESCAPED_UNICODE | JSON_UNESCAPED_SLASHES);
			exit;
		}
	}
	header($_SERVER['SERVER_PROTOCOL'] . ' 404 Unknown language');
	exit;
}

if(!defined('PLX_ROOT')) {
	exit;
}

class tinyEditor extends plxPlugin {

	const BEGIN_CODE = '<?php' . PHP_EOL;
	const END_CODE = PHP_EOL . '?>';

	public function __construct($default_lang) {

		# Appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		if(defined('PLX_ADMIN')) {
			# droits pour accèder à la page config.php du plugin
			$this->setConfigProfil(PROFIL_ADMIN);

			# Déclarations des hooks
			$scriptname = basename($_SERVER['SCRIPT_NAME'], '.php');
			if($scriptname == 'medias' or !empty($this->getParam($scriptname))) {
				foreach(array(
					'AdminFootEndBody',
					'plxAdminEditArticle',
					'AdminArticleTop',
				) as $hook) {
					$this->addHook($hook, $hook);
				}
			}
		}
	}

	private function enable() {
		$scriptname = basename($_SERVER['SCRIPT_NAME'], '.php');
		return (($scriptname == 'medias') or (intval($this->getParam($scriptname)) > 0));
	}

	/**
	 * Méthode qui convertit les liens absolus en liens relatifs pour les images et les documents
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function plxAdminEditArticle() {
		echo self::BEGIN_CODE;
		foreach(array('chapo', 'content') as $k) {
?>
$content['<?= $k ?>'] = str_replace('="' . $this->racine, '="', $content['<?= $k ?>']);
<?php
		}
		echo self::END_CODE;
	}

	/**
	 * Méthode qui convertit les liens relatifs en liens absolus pour les images et les documents
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function AdminArticleTop() {
		echo self::BEGIN_CODE;
?>
$chapo = plxUtils::rel2abs($plxAdmin->racine, $chapo);
$content = plxUtils::rel2abs($plxAdmin->racine, $content);
<?php
		echo self::END_CODE;
	}

	public function AdminFootEndBody() {
		/*
		 * https://emojipedia.org/
		 * https://emojigraph.org/
		 * */
		if(defined('PLX_ADMIN')) {
			global $plxAdmin;
			$options = array(
				'urlBase'		=> PLX_ROOT,
				'mediasManager'	=> $plxAdmin->racine . 'core/admin/medias.php',
				'lang'			=> $this->default_lang,
				'token'			=> plxToken::getTokenPostMethod(32, false),
				'emojies'		=> '👍,👍🏾,👏,👏🏾,✍️,🙏,🐧,🍓,🍒,🍅,🚔,🚂,🚠,☔,' .
					'⚡,☀️,⚽,🎮,🎁,🏅,🦺,📕,📔,✏️,🗝️,' .
					'🧽,🚿,✅,❌,👮🏼,👮🏻‍,️🕵🏻‍♂️,🕵🏽‍♀️,🍔,🍕,🏡',
			);
			$ext = '.min.js';
			$name = PLX_PLUGINS . __CLASS__ . '/' . __CLASS__ . '/' . __CLASS__;
			if(!file_exists($name . $ext)) {
				$ext = '.js';
			}
?>
<script type="text/javascript" src="<?= $name . $ext; ?>" data-options='<?= json_encode($options, JSON_UNESCAPED_SLASHES) ?>'></script>
<?php
		}
	}

}
?>
